@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef MOCK_SETTINGS_H
-#define MOCK_SETTINGS_H
+#pragma once
 
 #include "../src/private/decorationsettingsprivate.h"
 
@@ -14,8 +13,8 @@ public:
     explicit MockSettings(KDecoration2::DecorationSettings *parent);
 
     KDecoration2::BorderSize borderSize() const override;
-    QVector<KDecoration2::DecorationButtonType> decorationButtonsLeft() const override;
-    QVector<KDecoration2::DecorationButtonType> decorationButtonsRight() const override;
+    QList<KDecoration2::DecorationButtonType> decorationButtonsLeft() const override;
+    QList<KDecoration2::DecorationButtonType> decorationButtonsRight() const override;
     bool isAlphaChannelSupported() const override;
     bool isCloseOnDoubleClickOnMenu() const override;
     bool isOnAllDesktopsAvailable() const override;
@@ -27,5 +26,3 @@ private:
     bool m_onAllDesktopsAvailable = false;
     bool m_closeDoubleClickOnMenu = false;
 };
-
-#endif
