@@ -46,8 +46,8 @@ DecorationSettings::~DecorationSettings() = default;
 DELEGATE(bool, isOnAllDesktopsAvailable)
 DELEGATE(bool, isAlphaChannelSupported)
 DELEGATE(bool, isCloseOnDoubleClickOnMenu)
-DELEGATE(QVector<DecorationButtonType>, decorationButtonsLeft)
-DELEGATE(QVector<DecorationButtonType>, decorationButtonsRight)
+DELEGATE(QList<DecorationButtonType>, decorationButtonsLeft)
+DELEGATE(QList<DecorationButtonType>, decorationButtonsRight)
 DELEGATE(BorderSize, borderSize)
 DELEGATE(QFont, font)
 DELEGATE(QFontMetricsF, fontMetrics)
@@ -58,3 +58,5 @@ DELEGATE(int, largeSpacing)
 #undef DELEGATE
 
 }
+
+#include "moc_decorationsettings.cpp"
